==> media_proxy-test-20180802.083943-1-sources.jar: com/jz/jar/media/proxy/AgeProxy.java <==
package com.jz.jar.media.proxy;

import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import com.jz.common.utils.collection.ArrayMapTools;
import com.jz.jar.media.service.AgeGroupService;
import com.jz.jar.media.service.AgeTopicService;
import com.jz.jooq.media.tables.pojos.AgeGroup;
import com.jz.jooq.media.tables.pojos.AgeTopic;

@Component
public class AgeProxy {

	private static final Map<AgeGroup, List<String>> age2Topics = Maps.newLinkedHashMap();

	@Autowired
	private AgeGroupService ageGroupService;
	@Autowired
	private AgeTopicService ageTopicService;

	/** 加载年龄相关入缓存 */
	public void loadAgeCache() {
		List<AgeGroup> groups = ageGroupService.find();
		if (ArrayMapTools.isEmpty(groups)) {
			return;
		}
		// 获取年龄 => 分类
		Map<String, List<String>> tempAgeTopic = this.findAgeTopics();
		for (AgeGroup it : groups) {
			age2Topics.put(it, tempAgeTopic.get(it.getId()));
		}
	}

	private Map<String, List<String>> findAgeTopics() {
		List<AgeTopic> ageTopics = ageTopicService.find();
		if (ArrayMapTools.isEmpty(ageTopics))
			return Maps.newHashMap();
		Map<String, List<String>> aid2Topics = Maps.newHashMap();
		ageTopics.forEach(it -> {
			if (!aid2Topics.containsKey(it.getAid()))
				aid2Topics.put(it.getAid(), Lists.newArrayList());
			aid2Topics.get(it.getAid()).add(it.getTid());
		});
		return aid2Topics;
	}

	public List<AgeGroup> getAges() {
		return age2Topics.keySet().stream().collect(Collectors.toList());
	}

	public Map<AgeGroup, List<String>> getAge2Topics() {
		return Maps.newLinkedHashMap(age2Topics);
	}
}

==> media_proxy-test-20180803.033613-3-sources.jar: com/jz/jar/media/proxy/AgeProxy.java <==
package com.jz.jar.media.proxy;

import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Lazy;
import org.springframework.stereotype.Service;

import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import com.jz.common.utils.collection.ArrayMapTools;
import com.jz.jar.media.service.AgeGroupService;
import com.jz.jar.media.service.AgeTopicService;
import com.jz.jooq.media.tables.pojos.AgeGroup;
import com.jz.jooq.media.tables.pojos.AgeTopic;

@Lazy
@Service
public class AgeProxy {

	private static final Map<AgeGroup, List<String>> age2Topics = Maps.newLinkedHashMap();

	@Autowired
	private AgeGroupService ageGroupService;
	@Autowired
	private AgeTopicService ageTopicService;

	/** 加载年龄相关入缓存 */
	public void loadAgeCache() {
		List<AgeGroup> groups = ageGroupService.find();
		if (ArrayMapTools.isEmpty(groups)) {
			return;
		}
		// 获取年龄 => 分类
		Map<String, List<String>> tempAgeTopic = this.findAgeTopics();
		for (AgeGroup it : groups) {
			age2Topics.put(it, tempAgeTopic.get(it.getId()));
		}
	}

	private Map<String, List<String>> findAgeTopics() {
		List<AgeTopic> ageTopics = ageTopicService.find();
		if (ArrayMapTools.isEmpty(ageTopics))
			return Maps.newHashMap();
		Map<String, List<String>> aid2Topics = Maps.newHashMap();
		ageTopics.forEach(it -> {
			if (!aid2Topics.containsKey(it.getAid()))
				aid2Topics.put(it.getAid(), Lists.newArrayList());
			aid2Topics.get(it.getAid()).add(it.getTid());
		});
		return aid2Topics;
	}

	public List<AgeGroup> getAges() {
		return age2Topics.keySet().stream().collect(Collectors.toList());
	}

	public Map<AgeGroup, List<String>> getAge2Topics() {
		return Maps.newLinkedHashMap(age2Topics);
	}
}
